rpaframework-litellm
====================

This library enables LiteLLM Services for `RPA Framework`_
libraries.

The `LiteLLM Client`_ supports over 100+ LLMs.

.. _RPA Framework: https://rpaframework.org
.. _LiteLLM Client: https://docs.litellm.ai/docs/